# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/waylon/hacker/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Waylon\\Hacker\\": "packages/waylon/hacker/src",
            "Waylon\\Hacker\\Seeders\\": "packages/waylon/hacker/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Waylon\Hacker\Providers\HackerServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Hacker'  => Waylon\Hacker\Facades\Hacker::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Waylon\\Hacker\\Seeders\\HackerTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Waylon\Hacker\Providers\HackerServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Waylon\Hacker\Providers\HackerServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Waylon\Hacker\Providers\HackerServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/hacker/{modulename}

**User**

    http://path-to-route-folder/user/hacker/{modulename}

**Public**

    http://path-to-route-folder/hackers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/hacker/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/hacker/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/hacker/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/hacker/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/hacker/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/hacker/{modulename}/{slug}
    METHOD: GET